MDI_Mechanic
==============================
[//]: # (Badges)
[![codecov](https://codecov.io/gh/REPLACE_WITH_OWNER_ACCOUNT/MDI_Mechanic/branch/master/graph/badge.svg)](https://codecov.io/gh/REPLACE_WITH_OWNER_ACCOUNT/MDI_Mechanic/branch/master)


A tool for testing and developing MDI-enabled projects.

### Documentation

A tutorial for using MDI Mechanic is available [here](https://github.com/MolSSI-MDI/MDI_Mechanic/blob/master/docs/getting_started.rst).

### Copyright

Copyright (c) 2020, Taylor Barnes


#### Acknowledgements
 
Project based on the 
[Computational Molecular Science Python Cookiecutter](https://github.com/molssi/cookiecutter-cms) version 1.4.
